# Usage

Most users will only need to call `careful.httpx.make_careful_client`.

::: careful.httpx.make_careful_client
    options:
      annotations_path: brief
      show_signature: false
      show_root_heading: true


## cache storage


::: careful.httpx.MemoryCache
    options:
       heading_level: 3
       members: False
       show_root_heading: true

::: careful.httpx.FileCache
    options:
       heading_level: 3
       members: False
       show_root_heading: true

::: careful.httpx.SqliteCache
    options:
       heading_level: 3
       members: False
       show_root_heading: true

